@@ -473,7 +473,7 @@ jomo.glmer.MCMCchain <-
         }
       }
       if (is.null(start.imp.sub)) {
-        for (i in 1:length(Ysubimp)) if (is.na(Ysubimp[i])) Ysubimp[i]=mean(Ysubimp, na.rm = TRUE)
+        for (i in 1:length(Ysubimp)) if (is.na(Ysubimp[i])) Ysubimp[i]=sample(1:2,1)
       }
       Ysubcat <- c(Ysub)
       if (!is.null(Y2)) {
