@@ -47,8 +47,7 @@ jomo1rancathr <-
     for (i in 1:nrow(l2cov.start)) {
       for (j in 1:ncol(l2cov.start)) covuit[i,j]=l2cov.start[i,j]
     }   
-    ait=0
-    ait=a
+    ait=as.numeric(a)
     colnamycat<-colnames(Y.cat)
     colnamx<-colnames(X)
     colnamz<-colnames(Z)
@@ -95,11 +94,11 @@ jomo1rancathr <-
     meanobs<-colMeans(Yi,na.rm=TRUE)
     for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=rnorm(1,meanobs[j],1)
     if (meth=="fixed") {
-      .Call("jomo1ranmixhf", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nburn, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,out.iter, PACKAGE = "jomo")
-    }
-    if (meth=="random") {
-      .Call("jomo1ranmixhrC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nburn, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,a.prior,out.iter, PACKAGE = "jomo")
+      fixed=1    
+    } else {
+      fixed=0
     }
+    .Call("jomo1ranhrC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nburn, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,a.prior,out.iter, fixed, 0, PACKAGE = "jomo")
     #betapost[,,1]=bpost
     #upostall[,,1]=upost
     #omegapost[,,(1)]=opost
@@ -117,12 +116,7 @@ jomo1rancathr <-
       imp[(i*nrow(clus)+1):((i+1)*nrow(clus)), (ncol(Y)+ncol(X)+ncol(Z)+1)]=clus
       imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+2)]=c(1:nrow(Y))
       imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=i
-      if (meth=="fixed") {
-        .Call("jomo1ranmixhf", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nbetween, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,out.iter, PACKAGE = "jomo")
-      }
-      if (meth=="random") {
-        .Call("jomo1ranmixhrC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nbetween, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,a.prior, out.iter, PACKAGE = "jomo")
-      }
+      .Call("jomo1ranhrC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit,cpost,nbetween, l1cov.prior,l2cov.prior,Y.numcat, 0,ait,a.prior, out.iter, fixed, 0, PACKAGE = "jomo")
       betapost[,,(i-1)]=bpost
       upostall[,,(i-1)]=upost
       omegapost[,,(i-1)]=opost
